==> ark-18.12.3.tar.xz: ark-18.12.3/app/org.kde.ark.desktop.cmake <==
[Desktop Entry]
MimeType=@SUPPORTED_ARK_MIMETYPES@
GenericName=Archiving Tool
GenericName[af]=Argiveer Program
GenericName[ar]=أداة أرشفة
GenericName[bg]=Работа с архиви
GenericName[br]=Ostilh merañ an Dielloù
GenericName[bs]=Alatka za arhiviranje
GenericName[ca]=Eina d'arxivament
GenericName[ca@valencia]=Eina d'arxivament
GenericName[cs]=Archivační nástroj
GenericName[cy]=Erfyn Archifo 
GenericName[da]=Arkiveringsværktøj
GenericName[de]=Archivprogramm
GenericName[el]=Εργαλείο αρχειοθέτησης
GenericName[en_GB]=Archiving Tool
GenericName[eo]=Arkivilo
GenericName[es]=Archivador
GenericName[et]=Arhiivide haldamise rakendus
GenericName[eu]=Artxibatzeko tresna
GenericName[fa]=ابزار بایگانی
GenericName[fi]=Pakkausohjelma
GenericName[fr]=Outil d'archivage
GenericName[ga]=Uirlis Chartlannaithe
GenericName[gl]=Utilidade de arquivo
GenericName[he]=כלי לניהול ארכיונים
GenericName[hne]=अभिलेखन औजार
GenericName[hr]=Alat za arhiviranje
GenericName[hu]=Fájltömörítő
GenericName[ia]=Instrumento per archivar
GenericName[id]=Alat Pengarsipan
GenericName[is]=Safnskráaverkfæri
GenericName[it]=Strumento di archiviazione
GenericName[ja]=アーカイブツール
GenericName[kk]=Архивтеу құралы
GenericName[km]=ឧបករណ៍​ប័ណ្ណសារ
GenericName[ko]=압축 도구
GenericName[lt]=Archyvavimo priemonė
GenericName[lv]=Arhivēšanas rīks
GenericName[mk]=Алатка за архивирање
GenericName[mr]=संग्रह साधन
GenericName[ms]=Alatan Pengarkiban
GenericName[nb]=Arkiveringsverktøy
GenericName[nds]=Archievwarktüüch
GenericName[ne]=सङ्ग्रहण उपकरण
GenericName[nl]=Archiefgereedschap
GenericName[nn]=Arkiveringsverktøy
GenericName[pa]=ਅਕਾਇਵਿੰਗ ਟੂਲ
GenericName[pl]=Narzędzie do archiwizacji
GenericName[pt]=Ferramenta de Armazenamento
GenericName[pt_BR]=Ferramenta de Arquivamento
GenericName[ro]=Utilitar de arhivare
GenericName[ru]=Архиватор
GenericName[sk]=Archivačný nástroj
GenericName[sl]=Orodje za ravnanje z arhivi
GenericName[sq]=Mjeti Arkivues
GenericName[sr]=Алатка за архивирање
GenericName[sr@ijekavian]=Алатка за архивирање
GenericName[sr@ijekavianlatin]=Alatka za arhiviranje
GenericName[sr@latin]=Alatka za arhiviranje
GenericName[sv]=Arkiveringsverktyg
GenericName[ta]=காப்பக கருவி
GenericName[tg]=Асбобҳои Бойгонӣ
GenericName[th]=เครื่องมือจัดการแฟ้มจัดเก็บ
GenericName[tr]=Arşivleme Aracı
GenericName[ug]=ئارخىپ قورالى
GenericName[uk]=Засіб роботи з архівами
GenericName[uz]=Arxivlash vositasi
GenericName[uz@cyrillic]=Архивлаш воситаси
GenericName[vi]=Công Cụ Nén
GenericName[wa]=Usteye d' årtchivaedje
GenericName[xh]=Isixhobo Sokuphatha i Archive
GenericName[x-test]=xxArchiving Toolxx
GenericName[zh_CN]=压缩工具
GenericName[zh_TW]=壓縮工具
Name=Ark
Name[af]=Ark
Name[ar]=أرك
Name[bg]=Ark
Name[br]=Ark
Name[bs]=Ark
Name[ca]=Ark
Name[ca@valencia]=Ark
Name[cs]=Ark
Name[cy]=Ark
Name[da]=Ark
Name[de]=Ark
Name[el]=Ark
Name[en_GB]=Ark
Name[eo]=Arko
Name[es]=Ark
Name[et]=Ark
Name[eu]=Ark
Name[fi]=Ark
Name[fr]=Ark
Name[ga]=Ark
Name[gl]=Ark
Name[he]=Ark
Name[hne]=आर्क
Name[hr]=Ark
Name[hu]=Ark
Name[ia]=Ark
Name[id]=Ark
Name[is]=Ark
Name[it]=Ark
Name[ja]=Ark
Name[kk]=Ark
Name[km]=Ark
Name[ko]=Ark
Name[lt]=Ark
Name[lv]=Ark
Name[mk]=Ark
Name[mr]=आर्क
Name[ms]=Ark
Name[nb]=Ark
Name[nds]=Ark
Name[ne]=आर्क
Name[nl]=Ark
Name[nn]=Ark
Name[pa]=ਆਕ
Name[pl]=Ark
Name[pt]=Ark
Name[pt_BR]=Ark
Name[ro]=Ark
Name[ru]=Ark
Name[sk]=Ark
Name[sl]=Ark
Name[sq]=Ark
Name[sr]=Арк
Name[sr@ijekavian]=Арк
Name[sr@ijekavianlatin]=Ark
Name[sr@latin]=Ark
Name[sv]=Ark
Name[ta]=ஆர்க்
Name[tg]=Ark
Name[th]=อาร์ก
Name[tr]=Ark
Name[ug]=Ark
Name[uk]=Ark
Name[uz]=Ark
Name[uz@cyrillic]=Ark
Name[vi]=Ark
Name[wa]=Ark
Name[xh]=Ark
Name[x-test]=xxArkxx
Name[zh_CN]=Ark
Name[zh_TW]=Ark
Exec=ark %U
Icon=ark
X-DocPath=ark/index.html
Type=Application
Terminal=false
X-DBUS-StartupType=Multi
X-DBUS-ServiceName=org.kde.ark
Categories=Qt;KDE;Utility;Archiving;Compression;X-KDE-Utilities-File;
InitialPreference=3
Comment=Work with file archives
Comment[ca]=Treball amb arxius de fitxer
Comment[ca@valencia]=Treball amb arxius de fitxer
Comment[cs]=Práce s archivy souborů
Comment[da]=Arbejd med filarkiver
Comment[de]=Arbeiten mit Dateiarchiven
Comment[el]=Εργασία με αρχειοθήκες
Comment[en_GB]=Work with file archives
Comment[es]=Trabajar con archivos comprimidos
Comment[et]=Arhiivifailide käitlemine
Comment[eu]=Fitxategien artxiboekin lan egiteko
Comment[fi]=Käsittele tiedostoarkistoja
Comment[fr]=Travailler avec des archives
Comment[gl]=Traballa con arquivos de ficheiros
Comment[he]=עבוד עם קבצי ארכיונים
Comment[ia]=Trvalia con le archivos de file
Comment[id]=Bekerja dengan arsip-arsip file
Comment[is]=Vinna með safnskrár
Comment[it]=Lavora con gli archivi di file
Comment[ko]=압축 파일로 작업하기
Comment[lt]=Darbas su archyvais
Comment[nl]=Mert bestandsarchieven werken
Comment[nn]=Arbeid med filarkiv
Comment[pl]=Pracuj z archiwami plików
Comment[pt]=Lidar com pacotes em ficheiros
Comment[pt_BR]=Manipulação de arquivos compactados
Comment[ru]=Работа с архивами файлов
Comment[sk]=Práca s archívmi súborov
Comment[sl]=Delajte z datotečnimi arhivi
Comment[sr]=Рад са фајловима архива
Comment[sr@ijekavian]=Рад са фајловима архива
Comment[sr@ijekavianlatin]=Rad sa fajlovima arhiva
Comment[sr@latin]=Rad sa fajlovima arhiva
Comment[sv]=Arbeta med filarkiv
Comment[tr]=Arşiv dosyaları ile çalış
Comment[uk]=Робота з файловими архівами
Comment[x-test]=xxWork with file archivesxx
Comment[zh_CN]=处理归档文件
Comment[zh_TW]=檔案壓縮工具

==> ark-19.03.90.tar.xz: ark-19.03.90/app/org.kde.ark.desktop.cmake <==
[Desktop Entry]
MimeType=@SUPPORTED_ARK_MIMETYPES@
GenericName=Archiving Tool
GenericName[af]=Argiveer Program
GenericName[ar]=أداة أرشفة
GenericName[bg]=Работа с архиви
GenericName[br]=Ostilh merañ an Dielloù
GenericName[bs]=Alatka za arhiviranje
GenericName[ca]=Eina d'arxivament
GenericName[ca@valencia]=Eina d'arxivament
GenericName[cs]=Archivační nástroj
GenericName[cy]=Erfyn Archifo 
GenericName[da]=Arkiveringsværktøj
GenericName[de]=Archivprogramm
GenericName[el]=Εργαλείο αρχειοθέτησης
GenericName[en_GB]=Archiving Tool
GenericName[eo]=Arkivilo
GenericName[es]=Archivador
GenericName[et]=Arhiivide haldamise rakendus
GenericName[eu]=Artxibatzeko tresna
GenericName[fa]=ابزار بایگانی
GenericName[fi]=Pakkausohjelma
GenericName[fr]=Outil d'archivage
GenericName[ga]=Uirlis Chartlannaithe
GenericName[gl]=Utilidade de arquivo
GenericName[he]=כלי לניהול ארכיונים
GenericName[hne]=अभिलेखन औजार
GenericName[hr]=Alat za arhiviranje
GenericName[hu]=Fájltömörítő
GenericName[ia]=Instrumento per archivar
GenericName[id]=Alat Pengarsipan
GenericName[is]=Safnskráaverkfæri
GenericName[it]=Strumento di archiviazione
GenericName[ja]=アーカイブツール
GenericName[kk]=Архивтеу құралы
GenericName[km]=ឧបករណ៍​ប័ណ្ណសារ
GenericName[ko]=압축 도구
GenericName[lt]=Archyvavimo priemonė
GenericName[lv]=Arhivēšanas rīks
GenericName[mk]=Алатка за архивирање
GenericName[mr]=संग्रह साधन
GenericName[ms]=Alatan Pengarkiban
GenericName[nb]=Arkiveringsverktøy
GenericName[nds]=Archievwarktüüch
GenericName[ne]=सङ्ग्रहण उपकरण
GenericName[nl]=Archiefgereedschap
GenericName[nn]=Arkiveringsverktøy
GenericName[pa]=ਅਕਾਇਵ ਕਰਨ ਟੂਲ
GenericName[pl]=Narzędzie do archiwizacji
GenericName[pt]=Ferramenta de Armazenamento
GenericName[pt_BR]=Ferramenta de Arquivamento
GenericName[ro]=Utilitar de arhivare
GenericName[ru]=Архиватор
GenericName[sk]=Archivačný nástroj
GenericName[sl]=Orodje za ravnanje z arhivi
GenericName[sq]=Mjeti Arkivues
GenericName[sr]=Алатка за архивирање
GenericName[sr@ijekavian]=Алатка за архивирање
GenericName[sr@ijekavianlatin]=Alatka za arhiviranje
GenericName[sr@latin]=Alatka za arhiviranje
GenericName[sv]=Arkiveringsverktyg
GenericName[ta]=காப்பக கருவி
GenericName[tg]=Асбобҳои Бойгонӣ
GenericName[th]=เครื่องมือจัดการแฟ้มจัดเก็บ
GenericName[tr]=Arşivleme Aracı
GenericName[ug]=ئارخىپ قورالى
GenericName[uk]=Засіб роботи з архівами
GenericName[uz]=Arxivlash vositasi
GenericName[uz@cyrillic]=Архивлаш воситаси
GenericName[vi]=Công Cụ Nén
GenericName[wa]=Usteye d' årtchivaedje
GenericName[xh]=Isixhobo Sokuphatha i Archive
GenericName[x-test]=xxArchiving Toolxx
GenericName[zh_CN]=压缩工具
GenericName[zh_TW]=壓縮工具
Name=Ark
Name[af]=Ark
Name[ar]=أرك
Name[bg]=Ark
Name[br]=Ark
Name[bs]=Ark
Name[ca]=Ark
Name[ca@valencia]=Ark
Name[cs]=Ark
Name[cy]=Ark
Name[da]=Ark
Name[de]=Ark
Name[el]=Ark
Name[en_GB]=Ark
Name[eo]=Arko
Name[es]=Ark
Name[et]=Ark
Name[eu]=Ark
Name[fi]=Ark
Name[fr]=Ark
Name[ga]=Ark
Name[gl]=Ark
Name[he]=Ark
Name[hne]=आर्क
Name[hr]=Ark
Name[hu]=Ark
Name[ia]=Ark
Name[id]=Ark
Name[is]=Ark
Name[it]=Ark
Name[ja]=Ark
Name[kk]=Ark
Name[km]=Ark
Name[ko]=Ark
Name[lt]=Ark
Name[lv]=Ark
Name[mk]=Ark
Name[mr]=आर्क
Name[ms]=Ark
Name[nb]=Ark
Name[nds]=Ark
Name[ne]=आर्क
Name[nl]=Ark
Name[nn]=Ark
Name[pa]=ਆਕ
Name[pl]=Ark
Name[pt]=Ark
Name[pt_BR]=Ark
Name[ro]=Ark
Name[ru]=Ark
Name[sk]=Ark
Name[sl]=Ark
Name[sq]=Ark
Name[sr]=Арк
Name[sr@ijekavian]=Арк
Name[sr@ijekavianlatin]=Ark
Name[sr@latin]=Ark
Name[sv]=Ark
Name[ta]=ஆர்க்
Name[tg]=Ark
Name[th]=อาร์ก
Name[tr]=Ark
Name[ug]=Ark
Name[uk]=Ark
Name[uz]=Ark
Name[uz@cyrillic]=Ark
Name[vi]=Ark
Name[wa]=Ark
Name[xh]=Ark
Name[x-test]=xxArkxx
Name[zh_CN]=Ark
Name[zh_TW]=Ark
Exec=ark %U
Icon=ark
X-DocPath=ark/index.html
Type=Application
Terminal=false
X-DBUS-StartupType=Multi
X-DBUS-ServiceName=org.kde.ark
Categories=Qt;KDE;Utility;Archiving;Compression;X-KDE-Utilities-File;
InitialPreference=3
Comment=Work with file archives
Comment[ca]=Treball amb arxius de fitxer
Comment[ca@valencia]=Treball amb arxius de fitxer
Comment[cs]=Práce s archivy souborů
Comment[da]=Arbejd med filarkiver
Comment[de]=Arbeiten mit Dateiarchiven
Comment[el]=Εργασία με αρχειοθήκες
Comment[en_GB]=Work with file archives
Comment[es]=Trabajar con archivos comprimidos
Comment[et]=Arhiivifailide käitlemine
Comment[eu]=Fitxategien artxiboekin lan egiteko
Comment[fi]=Käsittele tiedostoarkistoja
Comment[fr]=Travailler avec des archives
Comment[gl]=Traballa con arquivos de ficheiros
Comment[he]=עבוד עם קבצי ארכיונים
Comment[ia]=Trvalia con le archivos de file
Comment[id]=Bekerja dengan arsip-arsip file
Comment[is]=Vinna með safnskrár
Comment[it]=Lavora con gli archivi di file
Comment[ko]=압축 파일로 작업하기
Comment[lt]=Darbas su archyvais
Comment[nl]=Mert bestandsarchieven werken
Comment[nn]=Arbeid med filarkiv
Comment[pl]=Pracuj z archiwami plików
Comment[pt]=Lidar com pacotes em ficheiros
Comment[pt_BR]=Manipulação de arquivos compactados
Comment[ru]=Работа с архивами файлов
Comment[sk]=Práca s archívmi súborov
Comment[sl]=Delajte z datotečnimi arhivi
Comment[sr]=Рад са фајловима архива
Comment[sr@ijekavian]=Рад са фајловима архива
Comment[sr@ijekavianlatin]=Rad sa fajlovima arhiva
Comment[sr@latin]=Rad sa fajlovima arhiva
Comment[sv]=Arbeta med filarkiv
Comment[tr]=Arşiv dosyaları ile çalış
Comment[uk]=Робота з файловими архівами
Comment[x-test]=xxWork with file archivesxx
Comment[zh_CN]=处理归档文件
Comment[zh_TW]=檔案壓縮工具
